/* $Id: os-sco.h,v 1.5 1999/12/02 01:08:30 chip Exp $
 *
 * Deliver configuration for SCO UNIX and Open Desktop (ODT).
 *
 * NOTE: If you have version UNIX 3.2 or 3.2v2, or ODT 1.0 or 1.1, and
 * have not installed the Security Supplement "unx257", I strongly
 * recommend that you do so.  It will make C2 less obtrusive and add
 * support for group vectors.  If you don't install "unx257", then you
 * must edit "local.h" to include the statement "#undef GROUP_VECTOR".
 *
 * $Log: os-sco.h,v $
 * Revision 1.5  1999/12/02 01:08:30  chip
 * Use <base-sysv.h>.
 *
 * Revision 1.4  1991/08/05 18:19:50  chip
 * Describe interaction of unx257 and group vectors.
 *
 * Revision 1.3  1991/06/04  18:25:42  chip
 * Lint can't deal with stdarg.
 *
 * Revision 1.2  1991/06/04  18:14:53  chip
 * Created.
 *
 */

/* Mostly it's System V. */

#include <base-sysv.h>

/* Then again... */

#define HH_UNISTD		/* Has <unistd.h>			*/

#ifndef lint
#define HH_STDARG		/* Has <stdarg.h>			*/
#undef  HH_VARARGS		/* Has <varargs.h>			*/
#endif

#undef  SYSV_USRMAIL		/* Mailboxes in /usr/mail, as per SysV	*/
